Struct libcst_native::SimpleString
source · pub struct SimpleString<'a> {
pub value: &'a str,
pub lpar: Vec<LeftParen<'a>>,
pub rpar: Vec<RightParen<'a>>,
}Fields
value: &'a strThe texual representation of the string, including quotes, prefix
characters, and any escape characters present in the original source code,
such as r"my string\n".
lpar: Vec<LeftParen<'a>>rpar: Vec<RightParen<'a>>Trait Implementations
sourceimpl<'a> Clone for SimpleString<'a>
impl<'a> Clone for SimpleString<'a>
sourcefn clone(&self) -> SimpleString<'a>
fn clone(&self) -> SimpleString<'a>
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl<'a> Codegen<'a> for SimpleString<'a>
impl<'a> Codegen<'a> for SimpleString<'a>
fn codegen(&self, state: &mut CodegenState<'a>)
sourceimpl<'a> Debug for SimpleString<'a>
impl<'a> Debug for SimpleString<'a>
sourceimpl<'a> Default for SimpleString<'a>
impl<'a> Default for SimpleString<'a>
sourcefn default() -> SimpleString<'a>
fn default() -> SimpleString<'a>
Returns the “default value” for a type. Read more
sourceimpl<'a> ParenthesizedNode<'a> for SimpleString<'a>
impl<'a> ParenthesizedNode<'a> for SimpleString<'a>
fn lpar(&self) -> &Vec<LeftParen<'a>>
fn rpar(&self) -> &Vec<RightParen<'a>>
fn with_parens(self, left: LeftParen<'a>, right: RightParen<'a>) -> Self
fn parenthesize<F>(&self, state: &mut CodegenState<'a>, f: F)where F: FnOnce(&mut CodegenState<'a>),
sourceimpl<'a> PartialEq<SimpleString<'a>> for SimpleString<'a>
impl<'a> PartialEq<SimpleString<'a>> for SimpleString<'a>
sourcefn eq(&self, other: &SimpleString<'a>) -> bool
fn eq(&self, other: &SimpleString<'a>) -> bool
This method tests for
self and other values to be equal, and is used
by ==.impl<'a> Eq for SimpleString<'a>
impl<'a> StructuralEq for SimpleString<'a>
impl<'a> StructuralPartialEq for SimpleString<'a>